@@ -12,32 +12,23 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __DEVHELP_H__
-#define __DEVHELP_H__
+#ifndef DEVHELP_H
+#define DEVHELP_H
 
-#include <glib.h>
+/* Include all the public headers. */
 
-/* Explicitly include all the exported headers */
-#include "dh-assistant.h"
 #include "dh-assistant-view.h"
-#include "dh-book-manager.h"
-#include "dh-language.h"
 #include "dh-book.h"
+#include "dh-book-manager.h"
 #include "dh-book-tree.h"
-#include "dh-error.h"
+#include "dh-completion.h"
+#include "dh-init.h"
 #include "dh-keyword-model.h"
 #include "dh-link.h"
 #include "dh-sidebar.h"
-#include "dh-window.h"
 
-G_BEGIN_DECLS
-
-void dh_init (void);
-
-G_END_DECLS
-
-#endif /* __DEVHELP_H__ */
+#endif /* DEVHELP_H */
