@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2012 Aleksander Morgado <aleksander@gnu.org>
+ * Copyright (C) 2017 Sébastien Wilmet <swilmet@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -12,14 +13,15 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DH_APP_H
 #define DH_APP_H
 
 #include <gtk/gtk.h>
+#include "dh-window.h"
 
 G_BEGIN_DECLS
 
@@ -41,22 +43,12 @@ struct _DhAppClass {
         GtkApplicationClass parent_class;
 };
 
-GType dh_app_get_type (void) G_GNUC_CONST;
+GType           dh_app_get_type                 (void) G_GNUC_CONST;
 
-DhApp         *dh_app_new               (void);
+DhApp *         dh_app_new                      (void);
 
-GtkWindow     *dh_app_peek_first_window (DhApp *app);
-GtkWindow     *dh_app_peek_assistant    (DhApp *app);
-
-void           dh_app_new_window        (DhApp *app);
-void           dh_app_quit              (DhApp *app);
-void           dh_app_search            (DhApp *app,
-                                         const gchar *keyword);
-void           dh_app_search_assistant  (DhApp *app,
-                                         const gchar *keyword);
-void           dh_app_raise             (DhApp *app);
-
-gboolean      _dh_app_has_app_menu      (DhApp *app);
+DhWindow *      dh_app_get_active_main_window   (DhApp    *app,
+                                                 gboolean  create_if_none);
 
 G_END_DECLS
 
