@@ -244,6 +244,7 @@ dh_assistant_view_set_link (DhAssistantView *view,
                 return TRUE;
         }
 
+        /* FIXME uri can be NULL. */
         uri = dh_link_get_uri (link);
         anchor = strrchr (uri, '#');
         if (anchor) {
@@ -397,7 +398,7 @@ dh_assistant_view_set_link (DhAssistantView *view,
                         dh_link_get_uri (link),
                         dh_link_get_name (link),
                         _("Book:"),
-                        dh_link_get_book_name (link),
+                        dh_link_get_book_title (link),
                         buf);
                 g_free (buf);
 
@@ -467,7 +468,7 @@ dh_assistant_view_search (DhAssistantView *view,
              books = g_list_next (books)) {
                 GList *l;
 
-                for (l = dh_book_get_keywords (DH_BOOK (books->data));
+                for (l = dh_book_get_links (DH_BOOK (books->data));
                      l && exact_link == NULL;
                      l = l->next) {
                         DhLinkType type;
