@@ -14,8 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -666,6 +666,7 @@ dh_preferences_show_dialog (GtkWindow *parent)
         if (parent != gtk_window_get_transient_for (GTK_WINDOW (prefs_dialog))) {
                 gtk_window_set_transient_for (GTK_WINDOW (prefs_dialog),
                                               parent);
+                gtk_window_set_destroy_with_parent (GTK_WINDOW (prefs_dialog), TRUE);
         }
 
         gtk_window_present (GTK_WINDOW (prefs_dialog));
