@@ -136,10 +136,7 @@ search_idle_cb (gpointer user_data)
         book_link = dh_book_tree_get_selected_book (priv->book_tree);
         book_id = book_link != NULL ? dh_link_get_book_id (book_link) : NULL;
 
-        /* Disconnect the model during the filter, for:
-         * 1. better performances.
-         * 2. clearing the selection.
-         */
+        /* Disconnect the model, see the doc of dh_keyword_model_filter(). */
         gtk_tree_view_set_model (priv->hitlist_view, NULL);
 
         exact_link = dh_keyword_model_filter (priv->hitlist_model,
@@ -192,6 +189,7 @@ hitlist_selection_changed_cb (GtkTreeSelection *selection,
                                     -1);
 
                 g_signal_emit (sidebar, signals[SIGNAL_LINK_SELECTED], 0, link);
+                dh_link_unref (link);
         }
 }
 
@@ -222,6 +220,7 @@ hitlist_button_press_cb (GtkTreeView    *hitlist_view,
                             -1);
 
         g_signal_emit (sidebar, signals[SIGNAL_LINK_SELECTED], 0, link);
+        dh_link_unref (link);
 
         /* Always propagate the event so the tree view can update
          * the selection etc.
@@ -282,6 +281,7 @@ entry_key_press_event_cb (GtkEntry    *entry,
                         gtk_editable_set_position (GTK_EDITABLE (entry), -1);
 
                         g_signal_emit (sidebar, signals[SIGNAL_LINK_SELECTED], 0, link);
+                        dh_link_unref (link);
 
                         return GDK_EVENT_STOP;
                 }
@@ -383,6 +383,13 @@ entry_insert_text_cb (GtkEntry    *entry,
                 priv->idle_complete_id = g_idle_add (complete_idle_cb, sidebar);
 }
 
+static void
+entry_stop_search_cb (GtkSearchEntry *entry,
+                      gpointer        user_data)
+{
+        gtk_entry_set_text (GTK_ENTRY (entry), "");
+}
+
 static void
 hitlist_cell_data_func (GtkTreeViewColumn *tree_column,
                         GtkCellRenderer   *cell,
@@ -435,6 +442,7 @@ hitlist_cell_data_func (GtkTreeViewColumn *tree_column,
                       "weight", weight,
                       NULL);
 
+        dh_link_unref (link);
         g_free (name);
 }
 
@@ -456,6 +464,9 @@ dh_sidebar_init (DhSidebar *sidebar)
         gtk_orientable_set_orientation (GTK_ORIENTABLE (sidebar),
                                         GTK_ORIENTATION_VERTICAL);
 
+        gtk_widget_set_hexpand (GTK_WIDGET (sidebar), TRUE);
+        gtk_widget_set_vexpand (GTK_WIDGET (sidebar), TRUE);
+
         /* Setup the search entry */
         priv->entry = GTK_ENTRY (gtk_search_entry_new ());
         gtk_widget_set_hexpand (GTK_WIDGET (priv->entry), TRUE);
@@ -484,6 +495,11 @@ dh_sidebar_init (DhSidebar *sidebar)
                           G_CALLBACK (entry_insert_text_cb),
                           sidebar);
 
+        g_signal_connect (priv->entry,
+                          "stop-search",
+                          G_CALLBACK (entry_stop_search_cb),
+                          NULL);
+
         /* Setup hitlist */
         priv->hitlist_model = dh_keyword_model_new ();
         priv->hitlist_view = GTK_TREE_VIEW (gtk_tree_view_new ());
