@@ -3,6 +3,7 @@
  * Copyright (C) 2001-2008 Imendio AB
  * Copyright (C) 2012 Aleksander Morgado <aleksander@gnu.org>
  * Copyright (C) 2012 Thomas Bechtold <toabctl@gnome.org>
+ * Copyright (C) 2015-2018 Sébastien Wilmet <swilmet@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -51,9 +52,9 @@ typedef struct {
         DhLink *selected_link;
 } DhWindowPrivate;
 
-static void           window_open_new_tab            (DhWindow        *window,
-                                                      const gchar     *location,
-                                                      gboolean         switch_focus);
+static void open_new_tab (DhWindow    *window,
+                          const gchar *location,
+                          gboolean     switch_focus);
 
 G_DEFINE_TYPE_WITH_PRIVATE (DhWindow, dh_window, GTK_TYPE_APPLICATION_WINDOW);
 
@@ -107,6 +108,9 @@ dh_window_class_init (DhWindowClass *klass)
         gtk_widget_class_bind_template_child_private (widget_class, DhWindow, notebook);
 }
 
+/* Can return NULL during initialization and finalization, so it's better to
+ * handle the NULL case with the return value of this function.
+ */
 static DhTab *
 get_active_tab (DhWindow *window)
 {
@@ -144,6 +148,50 @@ update_window_title (DhWindow *window)
         gtk_header_bar_set_title (priv->header_bar, title);
 }
 
+static void
+update_zoom_actions_sensitivity (DhWindow *window)
+{
+        DhWebView *web_view;
+        GAction *action;
+        gboolean enabled;
+
+        web_view = get_active_web_view (window);
+        if (web_view == NULL)
+                return;
+
+        enabled = dh_web_view_can_zoom_in (web_view);
+        action = g_action_map_lookup_action (G_ACTION_MAP (window), "zoom-in");
+        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
+
+        enabled = dh_web_view_can_zoom_out (web_view);
+        action = g_action_map_lookup_action (G_ACTION_MAP (window), "zoom-out");
+        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
+
+        enabled = dh_web_view_can_reset_zoom (web_view);
+        action = g_action_map_lookup_action (G_ACTION_MAP (window), "zoom-default");
+        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
+}
+
+static void
+update_back_forward_actions_sensitivity (DhWindow *window)
+{
+        DhWebView *web_view;
+        GAction *action;
+        gboolean enabled;
+
+        web_view = get_active_web_view (window);
+        if (web_view == NULL)
+                return;
+
+        enabled = webkit_web_view_can_go_back (WEBKIT_WEB_VIEW (web_view));
+        action = g_action_map_lookup_action (G_ACTION_MAP (window), "go-back");
+        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
+
+        enabled = webkit_web_view_can_go_forward (WEBKIT_WEB_VIEW (web_view));
+        action = g_action_map_lookup_action (G_ACTION_MAP (window), "go-forward");
+        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
+}
+
 static void
 new_tab_cb (GSimpleAction *action,
             GVariant      *parameter,
@@ -151,7 +199,7 @@ new_tab_cb (GSimpleAction *action,
 {
         DhWindow *window = DH_WINDOW (user_data);
 
-        window_open_new_tab (window, NULL, TRUE);
+        open_new_tab (window, NULL, TRUE);
 }
 
 static void
@@ -215,6 +263,9 @@ print_cb (GSimpleAction *action,
         WebKitPrintOperation *print_operation;
 
         web_view = get_active_web_view (window);
+        if (web_view == NULL)
+                return;
+
         print_operation = webkit_print_operation_new (WEBKIT_WEB_VIEW (web_view));
         webkit_print_operation_run_dialog (print_operation, GTK_WINDOW (window));
         g_object_unref (print_operation);
@@ -229,6 +280,11 @@ close_cb (GSimpleAction *action,
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
         gint page_num;
 
+        /* FIXME: the code here closes the current *tab*, but in help-overlay.ui
+         * it is documented as "Close the current window". Look for example at
+         * what gedit does, or other GNOME apps with a GtkNotebook plus Ctrl+W
+         * shortcut, and do the same.
+         */
         page_num = gtk_notebook_get_current_page (priv->notebook);
         gtk_notebook_remove_page (priv->notebook, page_num);
 }
@@ -255,10 +311,14 @@ copy_cb (GSimpleAction *action,
                                         dh_link_get_name (priv->selected_link),
                                         -1);
         } else {
-                WebKitWebView *web_view;
+                DhWebView *web_view;
 
-                web_view = WEBKIT_WEB_VIEW (get_active_web_view (window));
-                webkit_web_view_execute_editing_command (web_view, WEBKIT_EDITING_COMMAND_COPY);
+                web_view = get_active_web_view (window);
+                if (web_view == NULL)
+                        return;
+
+                webkit_web_view_execute_editing_command (WEBKIT_WEB_VIEW (web_view),
+                                                         WEBKIT_EDITING_COMMAND_COPY);
         }
 }
 
@@ -274,54 +334,17 @@ find_cb (GSimpleAction *action,
         gtk_widget_grab_focus (GTK_WIDGET (priv->search_entry));
 }
 
-static void
-window_update_zoom_actions_state (DhWindow *window)
-{
-        DhWebView *web_view;
-        GAction *action;
-        gboolean enabled;
-
-        web_view = get_active_web_view (window);
-
-        enabled = dh_web_view_can_zoom_in (web_view);
-        action = g_action_map_lookup_action (G_ACTION_MAP (window), "zoom-in");
-        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
-
-        enabled = dh_web_view_can_zoom_out (web_view);
-        action = g_action_map_lookup_action (G_ACTION_MAP (window), "zoom-out");
-        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
-
-        enabled = dh_web_view_can_reset_zoom (web_view);
-        action = g_action_map_lookup_action (G_ACTION_MAP (window), "zoom-default");
-        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
-}
-
-static void
-window_update_back_forward_actions_sensitivity (DhWindow *window)
-{
-        WebKitWebView *web_view;
-        GAction *action;
-        gboolean enabled;
-
-        web_view = WEBKIT_WEB_VIEW (get_active_web_view (window));
-
-        enabled = web_view != NULL ? webkit_web_view_can_go_back (web_view) : FALSE;
-        action = g_action_map_lookup_action (G_ACTION_MAP (window), "go-back");
-        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
-
-        enabled = web_view != NULL ? webkit_web_view_can_go_forward (web_view) : FALSE;
-        action = g_action_map_lookup_action (G_ACTION_MAP (window), "go-forward");
-        g_simple_action_set_enabled (G_SIMPLE_ACTION (action), enabled);
-}
-
 static void
 zoom_in_cb (GSimpleAction *action,
             GVariant      *parameter,
             gpointer       user_data)
 {
         DhWindow *window = DH_WINDOW (user_data);
+        DhWebView *web_view;
 
-        dh_web_view_zoom_in (get_active_web_view (window));
+        web_view = get_active_web_view (window);
+        if (web_view != NULL)
+                dh_web_view_zoom_in (web_view);
 }
 
 static void
@@ -330,8 +353,11 @@ zoom_out_cb (GSimpleAction *action,
              gpointer       user_data)
 {
         DhWindow *window = DH_WINDOW (user_data);
+        DhWebView *web_view;
 
-        dh_web_view_zoom_out (get_active_web_view (window));
+        web_view = get_active_web_view (window);
+        if (web_view != NULL)
+                dh_web_view_zoom_out (web_view);
 }
 
 static void
@@ -340,8 +366,11 @@ zoom_default_cb (GSimpleAction *action,
                  gpointer       user_data)
 {
         DhWindow *window = DH_WINDOW (user_data);
+        DhWebView *web_view;
 
-        dh_web_view_reset_zoom (get_active_web_view (window));
+        web_view = get_active_web_view (window);
+        if (web_view != NULL)
+                dh_web_view_reset_zoom (web_view);
 }
 
 static void
@@ -364,7 +393,8 @@ go_back_cb (GSimpleAction *action,
         DhWebView *web_view;
 
         web_view = get_active_web_view (window);
-        webkit_web_view_go_back (WEBKIT_WEB_VIEW (web_view));
+        if (web_view != NULL)
+                webkit_web_view_go_back (WEBKIT_WEB_VIEW (web_view));
 }
 
 static void
@@ -376,11 +406,12 @@ go_forward_cb (GSimpleAction *action,
         DhWebView *web_view;
 
         web_view = get_active_web_view (window);
-        webkit_web_view_go_forward (WEBKIT_WEB_VIEW (web_view));
+        if (web_view != NULL)
+                webkit_web_view_go_forward (WEBKIT_WEB_VIEW (web_view));
 }
 
 static void
-add_action_entries (DhWindow *window)
+add_actions (DhWindow *window)
 {
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
         GPropertyAction *property_action;
@@ -466,7 +497,8 @@ sidebar_link_selected_cb (DhSidebar *sidebar,
                 return;
 
         web_view = get_active_web_view (window);
-        webkit_web_view_load_uri (WEBKIT_WEB_VIEW (web_view), uri);
+        if (web_view != NULL)
+                webkit_web_view_load_uri (WEBKIT_WEB_VIEW (web_view), uri);
 
         g_free (uri);
 }
@@ -487,7 +519,11 @@ update_search_in_web_view (DhWindow  *window,
 static void
 update_search_in_active_web_view (DhWindow *window)
 {
-        update_search_in_web_view (window, get_active_web_view (window));
+        DhWebView *web_view;
+
+        web_view = get_active_web_view (window);
+        if (web_view != NULL)
+                update_search_in_web_view (window, web_view);
 }
 
 static void
@@ -513,6 +549,8 @@ search_previous_in_active_web_view (DhWindow *window)
         DhWebView *web_view;
 
         web_view = get_active_web_view (window);
+        if (web_view == NULL)
+                return;
 
         update_search_in_web_view (window, web_view);
         dh_web_view_search_previous (web_view);
@@ -524,6 +562,8 @@ search_next_in_active_web_view (DhWindow *window)
         DhWebView *web_view;
 
         web_view = get_active_web_view (window);
+        if (web_view == NULL)
+                return;
 
         update_search_in_web_view (window, web_view);
         dh_web_view_search_next (web_view);
@@ -620,8 +660,8 @@ notebook_switch_page_after_cb (GtkNotebook *notebook,
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
 
         update_window_title (window);
-        window_update_zoom_actions_state (window);
-        window_update_back_forward_actions_sensitivity (window);
+        update_zoom_actions_sensitivity (window);
+        update_back_forward_actions_sensitivity (window);
         update_search_in_active_web_view (window);
 
         if (new_page != NULL) {
@@ -647,7 +687,7 @@ dh_window_init (DhWindow *window)
 
         gtk_widget_init_template (GTK_WIDGET (window));
 
-        add_action_entries (window);
+        add_actions (window);
 
         app = GTK_APPLICATION (g_application_get_default ());
         if (!gtk_application_prefers_app_menu (app)) {
@@ -728,12 +768,57 @@ dh_window_init (DhWindow *window)
                                 G_CALLBACK (notebook_switch_page_after_cb),
                                 window);
 
-        window_open_new_tab (window, NULL, TRUE);
+        open_new_tab (window, NULL, TRUE);
 
         /* Focus search in sidebar by default. */
         dh_sidebar_set_search_focus (priv->sidebar);
 }
 
+static void
+web_view_title_notify_cb (DhWebView  *web_view,
+                          GParamSpec *param_spec,
+                          DhWindow   *window)
+{
+        if (web_view == get_active_web_view (window))
+                update_window_title (window);
+}
+
+static void
+web_view_zoom_level_notify_cb (DhWebView  *web_view,
+                               GParamSpec *pspec,
+                               DhWindow   *window)
+{
+        if (web_view == get_active_web_view (window))
+                update_zoom_actions_sensitivity (window);
+}
+
+/* FIXME: connect to this signal on the whole DhWindow widget instead? And call
+ * webkit_web_view_go_back/forward() on the active web view. Because when the
+ * WebKitWebView doesn't have the focus, currently this callback is not called.
+ */
+static gboolean
+web_view_button_press_event_cb (WebKitWebView  *web_view,
+                                GdkEventButton *event,
+                                DhWindow       *window)
+{
+        switch (event->button) {
+                /* Some mice emit button presses when the scroll wheel is tilted
+                 * to the side. Web browsers use them to navigate in history.
+                 */
+                case 8:
+                        webkit_web_view_go_back (web_view);
+                        return GDK_EVENT_STOP;
+                case 9:
+                        webkit_web_view_go_forward (web_view);
+                        return GDK_EVENT_STOP;
+
+                default:
+                        break;
+        }
+
+        return GDK_EVENT_PROPAGATE;
+}
+
 static gchar *
 find_equivalent_local_uri (const gchar *uri)
 {
@@ -795,10 +880,10 @@ out:
 }
 
 static gboolean
-window_web_view_decide_policy_cb (WebKitWebView            *web_view,
-                                  WebKitPolicyDecision     *policy_decision,
-                                  WebKitPolicyDecisionType  type,
-                                  DhWindow                 *window)
+web_view_decide_policy_cb (WebKitWebView            *web_view,
+                           WebKitPolicyDecision     *policy_decision,
+                           WebKitPolicyDecisionType  type,
+                           DhWindow                 *window)
 {
         const char *uri;
         WebKitNavigationPolicyDecision *navigation_decision;
@@ -819,7 +904,7 @@ window_web_view_decide_policy_cb (WebKitWebView            *web_view,
         state = webkit_navigation_action_get_modifiers (navigation_action);
         if (button == 2 || (button == 1 && state == GDK_CONTROL_MASK)) {
                 webkit_policy_decision_ignore (policy_decision);
-                window_open_new_tab (window, uri, FALSE);
+                open_new_tab (window, uri, FALSE);
                 return GDK_EVENT_STOP;
         }
 
@@ -860,50 +945,9 @@ web_view_load_changed_cb (WebKitWebView   *web_view,
 }
 
 static void
-window_web_view_title_changed_cb (DhWebView  *web_view,
-                                  GParamSpec *param_spec,
-                                  DhWindow   *window)
-{
-        if (web_view == get_active_web_view (window))
-                update_window_title (window);
-}
-
-static void
-web_view_zoom_level_notify_cb (DhWebView  *web_view,
-                               GParamSpec *pspec,
-                               DhWindow   *window)
-{
-        if (web_view == get_active_web_view (window))
-                window_update_zoom_actions_state (window);
-}
-
-static gboolean
-window_web_view_button_press_event_cb (WebKitWebView  *web_view,
-                                       GdkEventButton *event,
-                                       DhWindow       *window)
-{
-        switch (event->button) {
-                /* Some mice emit button presses when the scroll wheel is tilted
-                 * to the side. Web browsers use them to navigate in history.
-                 */
-                case 8:
-                        webkit_web_view_go_back (web_view);
-                        return GDK_EVENT_STOP;
-                case 9:
-                        webkit_web_view_go_forward (web_view);
-                        return GDK_EVENT_STOP;
-
-                default:
-                        break;
-        }
-
-        return GDK_EVENT_PROPAGATE;
-}
-
-static void
-window_open_new_tab (DhWindow    *window,
-                     const gchar *location,
-                     gboolean     switch_focus)
+open_new_tab (DhWindow    *window,
+              const gchar *location,
+              gboolean     switch_focus)
 {
         DhWindowPrivate *priv = dh_window_get_instance_private (window);
         DhTab *tab;
@@ -929,7 +973,7 @@ window_open_new_tab (DhWindow    *window,
 
         g_signal_connect (web_view,
                           "notify::title",
-                          G_CALLBACK (window_web_view_title_changed_cb),
+                          G_CALLBACK (web_view_title_notify_cb),
                           window);
 
         g_signal_connect (web_view,
@@ -939,12 +983,12 @@ window_open_new_tab (DhWindow    *window,
 
         g_signal_connect (web_view,
                           "button-press-event",
-                          G_CALLBACK (window_web_view_button_press_event_cb),
+                          G_CALLBACK (web_view_button_press_event_cb),
                           window);
 
         g_signal_connect (web_view,
                           "decide-policy",
-                          G_CALLBACK (window_web_view_decide_policy_cb),
+                          G_CALLBACK (web_view_decide_policy_cb),
                           window);
 
         g_signal_connect (web_view,
@@ -955,7 +999,7 @@ window_open_new_tab (DhWindow    *window,
         back_forward_list = webkit_web_view_get_back_forward_list (WEBKIT_WEB_VIEW (web_view));
         g_signal_connect_object (back_forward_list,
                                  "changed",
-                                 G_CALLBACK (window_update_back_forward_actions_sensitivity),
+                                 G_CALLBACK (update_back_forward_actions_sensitivity),
                                  window,
                                  G_CONNECT_AFTER | G_CONNECT_SWAPPED);
 
@@ -1028,6 +1072,9 @@ _dh_window_display_uri (DhWindow    *window,
         priv = dh_window_get_instance_private (window);
 
         web_view = get_active_web_view (window);
+        if (web_view == NULL)
+                return;
+
         webkit_web_view_load_uri (WEBKIT_WEB_VIEW (web_view), uri);
         dh_sidebar_select_uri (priv->sidebar, uri);
 }
